# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: region.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cregion.proto\x12\x06helium*\xf1\x02\n\x06region\x12\t\n\x05US915\x10\x00\x12\t\n\x05\x45U868\x10\x01\x12\t\n\x05\x45U433\x10\x02\x12\t\n\x05\x43N470\x10\x03\x12\r\n\x05\x43N779\x10\x04\x1a\x02\x08\x01\x12\t\n\x05\x41U915\x10\x05\x12\x0b\n\x07\x41S923_1\x10\x06\x12\t\n\x05KR920\x10\x07\x12\t\n\x05IN865\x10\x08\x12\x0b\n\x07\x41S923_2\x10\t\x12\x0b\n\x07\x41S923_3\x10\n\x12\x0b\n\x07\x41S923_4\x10\x0b\x12\x0c\n\x08\x41S923_1B\x10\x0c\x12\x0c\n\x08\x43\x44\x39\x30\x30_1A\x10\r\x12\t\n\x05RU864\x10\x0e\x12\x0b\n\x07\x45U868_A\x10\x0f\x12\x0b\n\x07\x45U868_B\x10\x10\x12\x0b\n\x07\x45U868_C\x10\x11\x12\x0b\n\x07\x45U868_D\x10\x12\x12\x0b\n\x07\x45U868_E\x10\x13\x12\x0b\n\x07\x45U868_F\x10\x14\x12\r\n\tAU915_SB1\x10\x15\x12\r\n\tAU915_SB2\x10\x16\x12\x0c\n\x08\x41S923_1A\x10\x17\x12\x0c\n\x08\x41S923_1C\x10\x18\x12\x0c\n\x08\x41S923_1D\x10\x19\x12\x0c\n\x08\x41S923_1E\x10\x1a\x12\x0c\n\x08\x41S923_1F\x10\x1b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'region_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGION.values_by_name["CN779"]._options = None
  _REGION.values_by_name["CN779"]._serialized_options = b'\010\001'
  _REGION._serialized_start=25
  _REGION._serialized_end=394
# @@protoc_insertion_point(module_scope)
